"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseHtml = exports.HtmlParser = void 0;
const VOID_TAGS = [
    'area',
    'base',
    'br',
    'hr',
    'img',
    'input',
    'link',
    'meta',
    'param',
    'command',
    'keygen',
    'source'
];
const OPEN_TAG_REGEX = /^<([a-zA-Z][a-zA-Z0-9\-]*)/;
const CLOSE_TAG_REGEX = /^<\/([a-zA-Z][a-zA-Z0-9\-]*)>/;
const TEXT_NODE_REGEX = /^([^<]+)/;
const ATTRIBUTE_REGEX = /^\s+([a-zA-Z][a-zA-Z0-9\-]+)="([^"]*)"/;
class HtmlParser {
    constructor(input) {
        this.root = { children: [] };
        this.remainingInput = input;
    }
    pull(regex, handler = () => { }) {
        const match = regex.exec(this.remainingInput);
        if (match !== null) {
            const [full_match, ...captures] = match;
            this.remainingInput = this.remainingInput.slice(full_match.length);
            handler(...captures);
            return true;
        }
        else {
            return false;
        }
    }
    parseAttributes(cursor) {
        while (this.pull(ATTRIBUTE_REGEX, (name, value) => {
            if (name === 'style') {
                cursor[name] = this.parseStyle(value);
            }
            else {
                cursor[name] = value;
            }
        })) { }
        if (!this.pull(/^\s*>/)) {
            throw new Error("Malformed open tag");
        }
    }
    parseContent(cursor) {
        let run = true;
        if (cursor === null) {
            cursor = {};
        }
        while (run && this.remainingInput.length > 0) {
            const success = (this.pull(OPEN_TAG_REGEX, (tag) => {
                const new_tag = { tag };
                cursor.children = cursor.children || [];
                cursor.children.push(new_tag);
                this.parseAttributes(new_tag);
                if (!VOID_TAGS.includes(tag.toLowerCase())) {
                    this.parseContent(new_tag);
                }
            }) ||
                this.pull(CLOSE_TAG_REGEX, (tag) => {
                    if (cursor.tag !== tag) {
                        throw new Error("Unmatched close tag");
                    }
                    run = false;
                }) ||
                this.pull(TEXT_NODE_REGEX, (text) => {
                    cursor.text = text;
                }));
            if (!success) {
                throw new Error("Parse error");
            }
        }
    }
    parseHtml() {
        var _a;
        this.parseContent(this.root);
        return ((_a = this.root.children) === null || _a === void 0 ? void 0 : _a.at(0)) || [];
    }
    parseStyle(styleString) {
        const style = {};
        const stylePairs = styleString.split(';');
        stylePairs.forEach((stylePair) => {
            const [property, value] = stylePair.split(':').map((s) => s.trim());
            const camelCaseProperty = this.kebabToCamelCase(property);
            style[camelCaseProperty] = value;
        });
        return style;
    }
    kebabToCamelCase(input) {
        return input.replace(/-([a-z])/g, (match, letter) => letter.toUpperCase());
    }
}
exports.HtmlParser = HtmlParser;
function parseHtml(input) {
    const parser = new HtmlParser(input);
    return parser.parseHtml();
}
exports.parseHtml = parseHtml;
